@@ -16,11 +16,10 @@ use strict;
     package OOP::Perlish::Class;
     use warnings;
     use strict;
-    our $VERSION = '0.45.0';
+    our $VERSION = 0.0100;
     use OOP::Perlish::Class::Accessor;
     use Tie::IxHash;
     use Exporter;
-    use IO::Handle;
 
     use constant OOP_PERLISH_CLASS_EMITLEVEL_FATAL   => 0;
     use constant OOP_PERLISH_CLASS_EMITLEVEL_ERROR   => 1;
@@ -112,15 +111,10 @@ use strict;
         @{ $self->{____CLASS_ISA} } = @{ $class . '::ISA' };
         use strict 'refs';
 
-        #for my $parent_class ( @{ $self->{____CLASS_ISA} } ) {
-        #    bless( $self, $parent_class );
-        #}
-
-        bless( $self, $class ); ## Bless so we can call _all_isa
-        for my $parent_class ( $self->_all_isa() ) {
+        for my $parent_class ( @{ $self->{____CLASS_ISA} } ) {
             bless( $self, $parent_class );
         }
-        bless( $self, $class ); ## Bless back into this class last so we deref correctly
+        bless( $self, $class );
         $self = $self->____initialize_object(%opts);
 
         return $self;
@@ -239,7 +233,7 @@ use strict;
         my ( $self, @msgs ) = @_;
 
         if( $self->_emitlevel() >= OOP_PERLISH_CLASS_EMITLEVEL_FATAL ) {
-            croak( map { my $l = defined($_) ? $_ : 'undef'; chomp($l); $l =~ s/^/FATAL: /gms; $l . $/ } @msgs );
+            croak( join( '', map { ( my $l = $_ ) =~ s/^/FATAL: /gms } @msgs ) . $/ );
         }
         return;
     }
@@ -248,21 +242,13 @@ use strict;
     ## Stub of a _preinit; note that init must return true or object initialization will fail
     ## This method does object initialization _before_ accessors have been set
     ############################################################################################
-    sub _preinit(@) {
-        my ($self, @args) = @_;
-        $self->_all_SUPER('_preinit', @args);
-        return 1; 
-    }
+    sub _preinit(@) { return 1; }
 
     ############################################################################################
     ## Stub of an _init; note that init must return true or object initialization will fail
     ## This method does object initialization _after_ accessors have been set
     ############################################################################################
-    sub _init(@) {
-        my ($self, @args) = @_;
-        $self->_all_SUPER('_init', @args);
-        return 1; 
-    }
+    sub _init(@) { return 1; }
 
     ############################################################################################
     ## name of the class which we use for accessors; overload if you want to use a different
@@ -301,37 +287,30 @@ use strict;
     ##   methods defined nearer-ancestors
     ##   methods defined in this-class
     ## )
-    ## now memoized, as this becomes a substantial performance hit otherwise.
     ############################################################################################
     sub _all_methods(@)
     {
         my ( $self, $class ) = @_;
         $class ||= ref($self) || $self;
 
-        our %____oop_perlish_class_all_methods;
+        my %all_methods = ();
 
-        unless(exists($____oop_perlish_class_all_methods{$class})) { 
-            my %all_methods = ();
+        ### preserve order so that methods defined in hiarchies are preserved in the order they
+        ### occur
+        tie %all_methods, q(Tie::IxHash);
 
-            ### preserve order so that methods defined in hiarchies are preserved in the order they
-            ### occur
-            tie %all_methods, q(Tie::IxHash);
-
-            for my $parent_class ( $self->_all_isa($class) ) {
-                no strict 'refs';
-                for my $symbol ( keys %{ '::' . $parent_class . '::' } ) {
-                    $all_methods{$symbol} = 1 if( bless( {}, $class )->can($symbol) );
-                }
-                use strict 'refs';
+        for my $parent_class ( $self->_all_isa($class) ) {
+            no strict 'refs';
+            for my $symbol ( keys %{ '::' . $parent_class . '::' } ) {
+                $all_methods{$symbol} = 1 if( bless( {}, $class )->can($symbol) );
             }
-
-            ### Reverse the order of methods found, so that for meta-programming iteration, we run
-            ### the methods defined in top-level derived classes last (so they can override
-            ### inherited methods return values and such)
-            $____oop_perlish_class_all_methods{$class} = [ reverse keys %all_methods ];
+            use strict 'refs';
         }
 
-        return( @{ $____oop_perlish_class_all_methods{$class} } );
+        ### Reverse the order of methods found, so that for meta-programming iteration, we run
+        ### the methods defined in top-level derived classes last (so they can override
+        ### inherited methods return values and such)
+        return reverse keys %all_methods;
     }
 
     ############################################################################################
@@ -358,28 +337,6 @@ use strict;
         return keys %{ $self->{____isa_hash}->{$class} };
     }
 
-
-    ############################################################################################
-    ## run a method in all immediate members of @ISA
-    ############################################################################################
-    sub _all_SUPER
-    {
-        my ($self, $method, @args) = @_;
-        my $root_class = __PACKAGE__;
-
-        for my $parent_class ( grep { !/^\Q$root_class\E$/ } @{ $self->{____CLASS_ISA} } ) {
-            if($parent_class->can($method)) {
-                no strict 'refs';
-                my $sub = *{ $parent_class . '::' . $method };
-                use strict;
-                if(*{ $sub }{CODE}) { 
-                    $sub->($self, @args);
-                }
-            }
-        }
-    }
-
-
     ############################################################################################
     ## DO NOT USE UNLESS YOU KNOW WHAT YOU ARE DOING!
     ############################################################################################
@@ -470,19 +427,19 @@ use strict;
     ## '_____oop_perlish_class__defer__required__fields__validation', set the key value pair
     ## 'defer_required_fields' to when we see that arg passed to a constructor (and its true)
     ############################################################################################
-    #sub _magic_constructor_arg_handler_defer_required(@)
-    #{
-    #    my ( $self, $opts ) = @_;
-    #
-    #    my $key = 'defer_required_fields';
-    #    my $defer_required_fields;
-    #
-    #    if( exists( $opts->{_____oop_perlish_class__defer__required__fields__validation} ) ) {
-    #        $defer_required_fields = $opts->{_____oop_perlish_class__defer__required__fields__validation};
-    #        delete $opts->{_____oop_perlish_class__defer__required__fields__validation};
-    #    }
-    #    return ( $key, $defer_required_fields );
-    #}
+    sub _magic_constructor_arg_handler_defer_required(@)
+    {
+        my ( $self, $opts ) = @_;
+
+        my $key = 'defer_required_fields';
+        my $defer_required_fields;
+
+        if( exists( $opts->{_____oop_perlish_class__defer__required__fields__validation} ) ) {
+            $defer_required_fields = $opts->{_____oop_perlish_class__defer__required__fields__validation};
+            delete $opts->{_____oop_perlish_class__defer__required__fields__validation};
+        }
+        return ( $key, $defer_required_fields );
+    }
 
     ############################################################################################
     ## List all classes which are derived from a given base class (or the class $self was
@@ -599,14 +556,13 @@ use strict;
         %{ $self->{____oop_perlish_class_opts} } = %opts;
 
         $self->____inherit_accessors();
-        $self->____pre_validate_opts(); #unless( $magic{defer_required_fields} );
-        ### XXX: unnessessary, and annoying XXX $self->____inherit_constructed_refs();
-        ### XXX: Might want to make a for (@ISA) { $_::_init(@_); } or similar for multiple_inheritance considerations.
-        $self->____initialize_required_fields();# unless( $magic{defer_required_fields} );
+        $self->____pre_validate_opts() unless( $magic{defer_required_fields} );
+        $self->____inherit_constructed_refs();
+        $self->____initialize_required_fields() unless( $magic{defer_required_fields} );
         return unless( $self->_preinit() );
         $self->____initialize_non_required_fields();
         return unless( $self->_init() );
-        $self->{__initialized} = 1; # unless($magic{defer_required_fields});
+        $self->{__initialized} = 1;
 
         return $self;
     }
@@ -683,8 +639,7 @@ use strict;
         }
 
         ### Assimilate inherited accessor references
-        #for my $parent_class ( @{ $self->{____CLASS_ISA} } ) {
-        for my $parent_class ( $self->_all_isa() ) {
+        for my $parent_class ( @{ $self->{____CLASS_ISA} } ) {
             if( $parent_class && bless( {}, $parent_class )->can('____OOP_PERLISH_CLASS_ACCESSORS') ) {
                 while( my ( $k, $v ) = each %{ $parent_class->____OOP_PERLISH_CLASS_ACCESSORS() } ) {
                     $self->____OOP_PERLISH_CLASS_ACCESSORS()->{$k} = $v unless( exists( $top_accessors{$k} ) );    #protect overloading
@@ -700,7 +655,7 @@ use strict;
     ############################################################################################
     ## FIXME: We only support deriving from blessed-hashref classes.
     ############################################################################################
-    sub ____inherit_constructed_refs
+    sub ____inherit_constructed_refs(@)
     {
         my ($self) = @_;
 
@@ -750,8 +705,7 @@ use strict;
 
             # FIXME: Does not cascade beyond @ISA, should traverse inheritance tree and ensure that all required fields are
             # provided for any hiararchy. ... does cascade via new, but only to ancesters who conform with us. unsure how to fix
-            #for my $parent_class ( @{ $self->{____CLASS_ISA} } ) {
-            for my $parent_class ( $self->_all_isa() ) {
+            for my $parent_class ( @{ $self->{____CLASS_ISA} } ) {
                 if( bless( {}, $parent_class )->can('____OOP_PERLISH_CLASS_REQUIRED_FIELDS') ) {
                     @required_fields{ @{ $parent_class->____OOP_PERLISH_CLASS_REQUIRED_FIELDS() } } =
                       @{ $parent_class->____OOP_PERLISH_CLASS_REQUIRED_FIELDS() };
@@ -1066,21 +1020,19 @@ Used internally, typically should not be overloaded -- See source.
 
 Walks @ISA of every parent, and infers their accessors, preserving hiarchial inheritance for overloaded accessors.
 
-=item $self->____pre_validate_opts()
+=item $self->____pre_validate_opts() unless( $magic{defer_required_fields} );
 
 Usually not overloaded, but occasionally you might want to do additional pre-validation prior to populating required fields. 
 
 Takes no arguments (other than $self), returns nothing; expected to croak if there is an error with the options passed to the constructor.
 
-=cut
+=item $self->____inherit_constructed_refs();
 
-#=item $self->____inherit_constructed_refs();
-#
-#Used internally, typically should not be overloaded -- See source.
-#
-#Inherits hash-references from all parent instances of '$self'
+Used internally, typically should not be overloaded -- See source.
 
-=item $self->____initialize_required_fields()
+Inherits hash-references from all parent instances of '$self'
+
+=item $self->____initialize_required_fields() unless( $magic{defer_required_fields} );
 
 Usually not overloaded, -- See source.
 
