@@ -461,12 +461,8 @@ use strict;
         my ($self) = @_;
         if($self->type() =~ m/REF/) {
             return $self->reference();
-        }
-        elsif($self->type() eq 'SCALAR') {
-            return undef;
-        }
-        else {
-            return( () );
+        } else {
+            return;
         }
     }
  
@@ -488,9 +484,6 @@ use strict;
         elsif( $self->is_set() == 0 ) {
             return $self->__appropriate_undef_value();
         }
-        elsif( $self->is_set() == -1 && ! $self->default_is_set() ) {
-            return $self->__appropriate_undef_value();
-        }
         elsif( $self->default_is_set() ) {
             return $self->__appropriate_undef_value() unless(defined( $self->default() ) );
             return $self->default();
